@@ -18,6 +18,10 @@ def index():
 def redirect_url():
     return render_template('redirect.html')
 
+@app.route('/updatedb')
+def updatedb_url():
+    return render_template('updatedb.html')
+
 @app.route('/home', methods=['GET'])
 def home():
     cursor = mysql.connection.cursor()
@@ -54,9 +58,9 @@ def add_db():
             cursor.execute("INSERT INTO robothistoric.TB_PROJECT ( Project_Id, Project_Name, Project_Desc, Project_Image, Created_Date, Last_Updated, Total_Executions, Recent_Pass_Perc, Overall_Pass_Perc) VALUES (0, '%s', '%s', '%s', NOW(), NOW(), 0, 0, 0);" % (db_name, db_desc, db_image))
             # create tables in created database
             use_db(cursor, db_name)
-            cursor.execute("Create table TB_EXECUTION ( Execution_Id INT NOT NULL auto_increment primary key, Execution_Date DATETIME, Execution_Desc TEXT, Execution_Total INT, Execution_Pass INT, Execution_Fail INT, Execution_Time FLOAT, Execution_STotal INT, Execution_SPass INT, Execution_SFail INT);")
-            cursor.execute("Create table TB_SUITE ( Suite_Id INT NOT NULL auto_increment primary key, Execution_Id INT, Suite_Name TEXT, Suite_Status CHAR(4), Suite_Total INT, Suite_Pass INT, Suite_Fail INT, Suite_Time FLOAT);")
-            cursor.execute("Create table TB_TEST ( Test_Id INT NOT NULL auto_increment primary key, Execution_Id INT, Test_Name TEXT, Test_Status CHAR(4), Test_Time FLOAT, Test_Error TEXT, Test_Comment TEXT);")
+            cursor.execute("Create table TB_EXECUTION ( Execution_Id INT NOT NULL auto_increment primary key, Execution_Date DATETIME, Execution_Desc TEXT, Execution_Total INT, Execution_Pass INT, Execution_Fail INT, Execution_Time FLOAT, Execution_STotal INT, Execution_SPass INT, Execution_SFail INT, Execution_Skip INT, Execution_SSkip INT);")
+            cursor.execute("Create table TB_SUITE ( Suite_Id INT NOT NULL auto_increment primary key, Execution_Id INT, Suite_Name TEXT, Suite_Status CHAR(4), Suite_Total INT, Suite_Pass INT, Suite_Fail INT, Suite_Time FLOAT, Suite_Skip INT);")
+            cursor.execute("Create table TB_TEST ( Test_Id INT NOT NULL auto_increment primary key, Execution_Id INT, Test_Name TEXT, Test_Status CHAR(4), Test_Time FLOAT, Test_Error TEXT, Test_Comment TEXT, Test_Assigned_To TEXT, Test_ETA TEXT, Test_Review_By TEXT, Test_Issue_Type TEXT, Test_Tag TEXT, Test_Updated DATETIME);")
             mysql.connection.commit()
         except Exception as e:
             print(str(e))
@@ -80,7 +84,7 @@ def dashboardAll(db):
 
     if results_data[0][0] > 0 and suite_results_data[0][0] > 0 and test_results_data[0][0] > 0:
 
-        cursor.execute("SELECT ROUND(AVG(Execution_Pass),0), ROUND(AVG(Execution_Fail),0), ROUND(AVG(Execution_Time),2) from TB_EXECUTION;")
+        cursor.execute("SELECT ROUND(AVG(Execution_Pass),0), ROUND(AVG(Execution_Fail),0), ROUND(AVG(Execution_Time),2), ROUND(AVG(Execution_Skip),0) from TB_EXECUTION;")
         exe_id_avg_data = cursor.fetchall()
 
         cursor.execute("SELECT ROUND((Execution_Pass/Execution_Total)*100, 2) from TB_EXECUTION;")
@@ -121,54 +125,63 @@ def dashboardRecent(db):
         else:
             exe_info = (exe_info[0], exe_info[0])
 
-        cursor.execute("SELECT Execution_Pass, Execution_Fail, Execution_Total, Execution_Time from TB_EXECUTION WHERE Execution_Id=%s;" % exe_info[0][0])
-        last_exe_data = cursor.fetchall()
+        # handle db columns not exist issue
+        try:
+            cursor.execute("SELECT Execution_Pass, Execution_Fail, Execution_Total, Execution_Time, Execution_Skip from TB_EXECUTION WHERE Execution_Id=%s;" % exe_info[0][0])
+            last_exe_data = cursor.fetchall()
 
-        cursor.execute("SELECT Execution_Pass, Execution_Fail, Execution_Total, Execution_Time from TB_EXECUTION WHERE Execution_Id=%s;" % exe_info[1][0])
-        prev_exe_data = cursor.fetchall()
+            cursor.execute("SELECT Execution_Pass, Execution_Fail, Execution_Total, Execution_Time, Execution_Skip from TB_EXECUTION WHERE Execution_Id=%s;" % exe_info[1][0])
+            prev_exe_data = cursor.fetchall()
 
-        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Status = 'FAIL' AND Test_Comment IS NULL;" % exe_info[0][0])
-        req_anal_data = cursor.fetchall()
+            cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Status = 'FAIL' AND Test_Comment IS NULL;" % exe_info[0][0])
+            req_anal_data = cursor.fetchall()
 
-        cursor.execute("SELECT ROUND(AVG(Suite_Time),2) from TB_SUITE WHERE Execution_Id=%s;" % exe_info[0][0])
-        suite_avg_dur_data = cursor.fetchall()
+            cursor.execute("SELECT ROUND(AVG(Suite_Time),2) from TB_SUITE WHERE Execution_Id=%s;" % exe_info[0][0])
+            suite_avg_dur_data = cursor.fetchall()
 
-        cursor.execute("SELECT ROUND(AVG(Test_Time),2) from TB_TEST WHERE Execution_Id=%s;" % exe_info[0][0])
-        test_avg_dur_data = cursor.fetchall()
+            cursor.execute("SELECT ROUND(AVG(Test_Time),2) from TB_TEST WHERE Execution_Id=%s;" % exe_info[0][0])
+            test_avg_dur_data = cursor.fetchall()
 
-        cursor.execute("SELECT b.Suite_Name, a.Suite_Fail, b.Occurence from TB_SUITE a INNER JOIN (Select Suite_Name, Count(Suite_Name) as Occurence From TB_SUITE WHERE Suite_Status = 'FAIL' AND Execution_Id>=%s GROUP BY Suite_Name HAVING COUNT(Suite_Name) > 1) b ON a.Suite_Name = b.Suite_Name WHERE Suite_Status='FAIL' AND Execution_Id=%s ORDER BY b.Occurence DESC, a.Suite_Fail DESC LIMIT 5;" % (exe_info[-1][0], exe_info[0][0]))
-        common_failed_suites = cursor.fetchall()
-    
-        cursor.execute("SELECT COUNT(*) From (SELECT Test_Name, Execution_Id From TB_TEST WHERE Test_Status='FAIL' AND Execution_Id >= %s GROUP BY Test_Name HAVING COUNT(Test_Name) = 1) AS T WHERE Execution_Id=%s" % (exe_info[1][0],exe_info[0][0]))
-        new_failed_tests_count = cursor.fetchall()
-
-        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Comment LIKE '%%Application_Issue%%';" % exe_info[0][0])
-        app_failure_anl_count = cursor.fetchall()
-
-        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Comment LIKE '%%Automation_Issue%%';" % exe_info[0][0])
-        auto_failure_anl_count = cursor.fetchall()
-
-        # required analysis percentage
-        if last_exe_data[0][1] > 0 and last_exe_data[0][1] != req_anal_data[0][0]:
-            req_anal_perc_data = round( ((last_exe_data[0][1] - req_anal_data[0][0]) / last_exe_data[0][1])*100  ,2)
-        else:
-            req_anal_perc_data = 0
+            cursor.execute("SELECT b.Suite_Name, a.Suite_Fail, b.Occurence from TB_SUITE a INNER JOIN (Select Suite_Name, Count(Suite_Name) as Occurence From TB_SUITE WHERE Suite_Status = 'FAIL' AND Execution_Id>=%s GROUP BY Suite_Name HAVING COUNT(Suite_Name) > 1) b ON a.Suite_Name = b.Suite_Name WHERE Suite_Status='FAIL' AND Execution_Id=%s ORDER BY b.Occurence DESC, a.Suite_Fail DESC LIMIT 5;" % (exe_info[-1][0], exe_info[0][0]))
+            common_failed_suites = cursor.fetchall()
         
-        new_tests_count = exe_info[0][1] - exe_info[1][1]
-        passed_test_dif = last_exe_data[0][0] - prev_exe_data[0][0]
-        failed_test_dif = prev_exe_data[0][1] - last_exe_data[0][1]
+            cursor.execute("SELECT COUNT(*) From (SELECT Test_Name, Execution_Id From TB_TEST WHERE Test_Status='FAIL' AND Execution_Id >= %s GROUP BY Test_Name HAVING COUNT(Test_Name) = 1) AS T WHERE Execution_Id=%s" % (exe_info[1][0],exe_info[0][0]))
+            new_failed_tests_count = cursor.fetchall()
 
-        return render_template('dashboardRecent.html', last_exe_data=last_exe_data, exe_info=exe_info,
-         prev_exe_data=prev_exe_data, new_failed_tests_count=new_failed_tests_count,
-         req_anal_data=req_anal_data, app_failure_anl_count=app_failure_anl_count,
-         req_anal_perc_data=req_anal_perc_data, auto_failure_anl_count=auto_failure_anl_count,
-         new_tests_count=new_tests_count,
-         passed_test_dif=passed_test_dif,
-         failed_test_dif=failed_test_dif,
-         suite_avg_dur_data=suite_avg_dur_data,
-         test_avg_dur_data=test_avg_dur_data,
-         common_failed_suites=common_failed_suites,
-         db_name=db)
+            cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Issue_Type LIKE '%%Application%%';" % exe_info[0][0])
+            app_failure_anl_count = cursor.fetchall()
+
+            cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Issue_Type LIKE '%%Automation%%';" % exe_info[0][0])
+            auto_failure_anl_count = cursor.fetchall()
+
+            cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Issue_Type LIKE '%%Other%%';" % exe_info[0][0])
+            other_failure_anl_count = cursor.fetchall()
+
+            # required analysis percentage
+            if last_exe_data[0][1] > 0 and last_exe_data[0][1] != req_anal_data[0][0]:
+                req_anal_perc_data = round( ((last_exe_data[0][1] - req_anal_data[0][0]) / last_exe_data[0][1])*100  ,2)
+            else:
+                req_anal_perc_data = 0
+            
+            new_tests_count = exe_info[0][1] - exe_info[1][1]
+            passed_test_dif = last_exe_data[0][0] - prev_exe_data[0][0]
+            failed_test_dif = prev_exe_data[0][1] - last_exe_data[0][1]
+            skipped_test_dif = prev_exe_data[0][4] - last_exe_data[0][4]
+
+            return render_template('dashboardRecent.html', last_exe_data=last_exe_data, exe_info=exe_info,
+            prev_exe_data=prev_exe_data, new_failed_tests_count=new_failed_tests_count,
+            req_anal_data=req_anal_data, app_failure_anl_count=app_failure_anl_count,
+            req_anal_perc_data=req_anal_perc_data, auto_failure_anl_count=auto_failure_anl_count,
+            new_tests_count=new_tests_count,other_failure_anl_count=other_failure_anl_count,
+            passed_test_dif=passed_test_dif,
+            failed_test_dif=failed_test_dif,
+            skipped_test_dif=skipped_test_dif,
+            suite_avg_dur_data=suite_avg_dur_data,
+            test_avg_dur_data=test_avg_dur_data,
+            common_failed_suites=common_failed_suites,
+            db_name=db)
+        except:
+            return redirect(url_for('updatedb_url'))
 
     else:
         return redirect(url_for('redirect_url'))
@@ -195,10 +208,10 @@ def eid_dashboard(db, eid):
         else:
             exe_info = (exe_info[0], exe_info[0])
 
-        cursor.execute("SELECT Execution_Pass, Execution_Fail, Execution_Total, Execution_Time from TB_EXECUTION WHERE Execution_Id=%s;" % exe_info[0][0])
+        cursor.execute("SELECT Execution_Pass, Execution_Fail, Execution_Total, Execution_Time, Execution_Skip from TB_EXECUTION WHERE Execution_Id=%s;" % exe_info[0][0])
         last_exe_data = cursor.fetchall()
 
-        cursor.execute("SELECT Execution_Pass, Execution_Fail, Execution_Total, Execution_Time from TB_EXECUTION WHERE Execution_Id=%s;" % exe_info[1][0])
+        cursor.execute("SELECT Execution_Pass, Execution_Fail, Execution_Total, Execution_Time, Execution_Skip from TB_EXECUTION WHERE Execution_Id=%s;" % exe_info[1][0])
         prev_exe_data = cursor.fetchall()
 
         cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Status = 'FAIL' AND Test_Comment IS NULL;" % exe_info[0][0])
@@ -216,12 +229,15 @@ def eid_dashboard(db, eid):
         cursor.execute("SELECT COUNT(*) From (SELECT Test_Name, Execution_Id From TB_TEST WHERE Test_Status='FAIL' AND Execution_Id >= %s GROUP BY Test_Name HAVING COUNT(Test_Name) = 1) AS T WHERE Execution_Id=%s" % (exe_info[1][0],exe_info[0][0]))
         new_failed_tests_count = cursor.fetchall()
 
-        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Comment LIKE '%%Application_Issue%%';" % exe_info[0][0])
+        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Issue_Type LIKE '%%Application%%';" % exe_info[0][0])
         app_failure_anl_count = cursor.fetchall()
 
-        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Comment LIKE '%%Automation_Issue%%';" % exe_info[0][0])
+        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Issue_Type LIKE '%%Automation%%';" % exe_info[0][0])
         auto_failure_anl_count = cursor.fetchall()
 
+        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Issue_Type LIKE '%%Other%%';" % exe_info[0][0])
+        other_failure_anl_count = cursor.fetchall()
+
         # required analysis percentage
         if last_exe_data[0][1] > 0 and last_exe_data[0][1] != req_anal_data[0][0]:
             req_anal_perc_data = round( ((last_exe_data[0][1] - req_anal_data[0][0]) / last_exe_data[0][1])*100  ,2)
@@ -231,14 +247,16 @@ def eid_dashboard(db, eid):
         new_tests_count = exe_info[0][1] - exe_info[1][1]
         passed_test_dif = last_exe_data[0][0] - prev_exe_data[0][0]
         failed_test_dif = prev_exe_data[0][1] - last_exe_data[0][1]
+        skipped_test_dif = prev_exe_data[0][4] - last_exe_data[0][4]
 
         return render_template('dashboardByEid.html', last_exe_data=last_exe_data, exe_info=exe_info,
          prev_exe_data=prev_exe_data, new_failed_tests_count=new_failed_tests_count,
          req_anal_data=req_anal_data, app_failure_anl_count=app_failure_anl_count,
          req_anal_perc_data=req_anal_perc_data, auto_failure_anl_count=auto_failure_anl_count,
-         new_tests_count=new_tests_count,
+         new_tests_count=new_tests_count, other_failure_anl_count=other_failure_anl_count,
          passed_test_dif=passed_test_dif,
          failed_test_dif=failed_test_dif,
+         skipped_test_dif=skipped_test_dif,
          suite_avg_dur_data=suite_avg_dur_data,
          test_avg_dur_data=test_avg_dur_data,
          common_failed_suites=common_failed_suites,
@@ -264,10 +282,10 @@ def dashboardRecentFive(db):
         cursor.execute("SELECT Execution_Id, Execution_Total from TB_EXECUTION order by Execution_Id desc LIMIT 5;")
         exe_info = cursor.fetchall()
 
-        cursor.execute("SELECT ROUND(AVG(Execution_Pass),0), ROUND(AVG(Execution_Fail),0), ROUND(AVG(Execution_Time),2) from TB_EXECUTION WHERE Execution_Id >= %s;" % exe_info[-1][0])
+        cursor.execute("SELECT ROUND(AVG(Execution_Pass),0), ROUND(AVG(Execution_Fail),0), ROUND(AVG(Execution_Time),2), ROUND(AVG(Execution_Skip),0) from TB_EXECUTION WHERE Execution_Id >= %s;" % exe_info[-1][0])
         exe_id_avg_data = cursor.fetchall()
 
-        cursor.execute("SELECT Execution_Id, Execution_Pass, Execution_Fail, Execution_Time from TB_EXECUTION order by Execution_Id desc LIMIT 5;")
+        cursor.execute("SELECT Execution_Id, Execution_Pass, Execution_Fail, Execution_Time, Execution_Skip from TB_EXECUTION order by Execution_Id desc LIMIT 5;")
         exe_id_filter_data = cursor.fetchall()
 
         cursor.execute("SELECT b.Suite_Name, a.Suite_Fail, b.Occurence from TB_SUITE a INNER JOIN (Select Suite_Name, Count(Suite_Name) as Occurence From TB_SUITE WHERE Suite_Status = 'FAIL' AND Execution_Id>=%s GROUP BY Suite_Name HAVING COUNT(Suite_Name) > 1) b ON a.Suite_Name = b.Suite_Name WHERE Suite_Status='FAIL' AND Execution_Id=%s ORDER BY b.Occurence DESC, a.Suite_Fail DESC LIMIT 5;" % (exe_info[-1][0], exe_info[0][0]))
@@ -277,7 +295,7 @@ def dashboardRecentFive(db):
         new_tests = exe_info[0][1] - exe_info[-1][1]
 
         return render_template('dashboardRecentFive.html', exe_id_avg_data=exe_id_avg_data,
-         exe_id_filter_data=exe_id_filter_data,
+         exe_id_filter_data=exe_id_filter_data, results_data=results_data,
          common_failed_suites=common_failed_suites,
          new_tests=new_tests,
          db_name=db)
@@ -302,10 +320,10 @@ def dashboardRecentTen(db):
         cursor.execute("SELECT Execution_Id, Execution_Total from TB_EXECUTION order by Execution_Id desc LIMIT 10;")
         exe_info = cursor.fetchall()
 
-        cursor.execute("SELECT ROUND(AVG(Execution_Pass),0), ROUND(AVG(Execution_Fail),0), ROUND(AVG(Execution_Time),2) from TB_EXECUTION WHERE Execution_Id >= %s;" % exe_info[-1][0])
+        cursor.execute("SELECT ROUND(AVG(Execution_Pass),0), ROUND(AVG(Execution_Fail),0), ROUND(AVG(Execution_Time),2), ROUND(AVG(Execution_Skip),0) from TB_EXECUTION WHERE Execution_Id >= %s;" % exe_info[-1][0])
         exe_id_avg_data = cursor.fetchall()
 
-        cursor.execute("SELECT Execution_Id, Execution_Pass, Execution_Fail, Execution_Time from TB_EXECUTION order by Execution_Id desc LIMIT 10;")
+        cursor.execute("SELECT Execution_Id, Execution_Pass, Execution_Fail, Execution_Time, Execution_Skip from TB_EXECUTION order by Execution_Id desc LIMIT 10;")
         exe_id_filter_data = cursor.fetchall()
 
         cursor.execute("SELECT b.Suite_Name, a.Suite_Fail, b.Occurence from TB_SUITE a INNER JOIN (Select Suite_Name, Count(Suite_Name) as Occurence From TB_SUITE WHERE Suite_Status = 'FAIL' AND Execution_Id>=%s GROUP BY Suite_Name HAVING COUNT(Suite_Name) > 1) b ON a.Suite_Name = b.Suite_Name WHERE Suite_Status='FAIL' AND Execution_Id=%s ORDER BY b.Occurence DESC, a.Suite_Fail DESC LIMIT 5;" % (exe_info[-1][0], exe_info[0][0]))
@@ -315,7 +333,7 @@ def dashboardRecentTen(db):
         new_tests = exe_info[0][1] - exe_info[-1][1]
 
         return render_template('dashboardRecentTen.html', exe_id_avg_data=exe_id_avg_data,
-         exe_id_filter_data=exe_id_filter_data,
+         exe_id_filter_data=exe_id_filter_data, results_data=results_data,
          common_failed_suites=common_failed_suites,
          new_tests=new_tests,
          db_name=db)
@@ -340,10 +358,10 @@ def dashboardRecentThirty(db):
         cursor.execute("SELECT Execution_Id, Execution_Total from TB_EXECUTION order by Execution_Id desc LIMIT 30;")
         exe_info = cursor.fetchall()
 
-        cursor.execute("SELECT ROUND(AVG(Execution_Pass),0), ROUND(AVG(Execution_Fail),0), ROUND(AVG(Execution_Time),2) from TB_EXECUTION WHERE Execution_Id >= %s;" % exe_info[-1][0])
+        cursor.execute("SELECT ROUND(AVG(Execution_Pass),0), ROUND(AVG(Execution_Fail),0), ROUND(AVG(Execution_Time),2), ROUND(AVG(Execution_Skip),0) from TB_EXECUTION WHERE Execution_Id >= %s;" % exe_info[-1][0])
         exe_id_avg_data = cursor.fetchall()
 
-        cursor.execute("SELECT Execution_Id, Execution_Pass, Execution_Fail, Execution_Time from TB_EXECUTION order by Execution_Id desc LIMIT 30;")
+        cursor.execute("SELECT Execution_Id, Execution_Pass, Execution_Fail, Execution_Time, Execution_Skip from TB_EXECUTION order by Execution_Id desc LIMIT 30;")
         exe_id_filter_data = cursor.fetchall()
 
         cursor.execute("SELECT b.Suite_Name, a.Suite_Fail, b.Occurence from TB_SUITE a INNER JOIN (Select Suite_Name, Count(Suite_Name) as Occurence From TB_SUITE WHERE Suite_Status = 'FAIL' AND Execution_Id>=%s GROUP BY Suite_Name HAVING COUNT(Suite_Name) > 1) b ON a.Suite_Name = b.Suite_Name WHERE Suite_Status='FAIL' AND Execution_Id=%s ORDER BY b.Occurence DESC, a.Suite_Fail DESC LIMIT 5;" % (exe_info[-1][0], exe_info[0][0]))
@@ -353,7 +371,7 @@ def dashboardRecentThirty(db):
         new_tests = exe_info[0][1] - exe_info[-1][1]
 
         return render_template('dashboardRecentThirty.html', exe_id_avg_data=exe_id_avg_data,
-         exe_id_filter_data=exe_id_filter_data,
+         exe_id_filter_data=exe_id_filter_data, results_data=results_data,
          common_failed_suites=common_failed_suites,
          new_tests=new_tests,
          db_name=db)
@@ -407,18 +425,13 @@ def tmetrics(db):
     cursor = mysql.connection.cursor()
     use_db(cursor, db)
     if request.method == "POST":
-        try:
-            userField = request.form['user']
-            issueField = request.form['issue']
-        except:
-            pass
-        textField = request.form['textField']
-        rowField = request.form['rowField']
-        try:
-            comment = """<b class="text-muted">Review By: </b>""" + str(userField) + """\n</br><b class="text-muted">Issue Type: </b>""" + str(issueField) + """\n</br><b class="text-muted">Comment: </b>""" + str(textField)
-        except:
-            comment = str(textField)
-        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\' WHERE Test_Id=%s;' % (str(comment), str(rowField)))
+        issue_type = request.form['issue']
+        review_by = request.form['reviewby']
+        assign_to = request.form['assignto']
+        eta = request.form['eta']
+        comment = request.form['comment']
+        rowid = request.form['rowid']
+        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\', Test_Assigned_To=\'%s\', Test_ETA=\'%s\', Test_Review_By=\'%s\', Test_Issue_Type=\'%s\', Test_Updated=now() WHERE Test_Id=%s;' % (str(comment), str(assign_to), str(eta), str(review_by), str(issue_type), str(rowid)))
         mysql.connection.commit()
 
     # Get last row execution ID
@@ -452,18 +465,13 @@ def eid_tmetrics(db, eid):
     cursor = mysql.connection.cursor()
     use_db(cursor, db)
     if request.method == "POST":
-        try:
-            userField = request.form['user']
-            issueField = request.form['issue']
-        except:
-            pass
-        textField = request.form['textField']
-        rowField = request.form['rowField']
-        try:
-            comment = """<b class="text-muted">Review By: </b>""" + str(userField) + """\n</br><b class="text-muted">Issue Type: </b>""" + str(issueField) + """\n</br><b class="text-muted">Comment: </b>""" + str(textField)
-        except:
-            comment = str(textField)
-        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\' WHERE Test_Id=%s;' % (str(comment), str(rowField)))
+        issue_type = request.form['issue']
+        review_by = request.form['reviewby']
+        assign_to = request.form['assignto']
+        eta = request.form['eta']
+        comment = request.form['comment']
+        rowid = request.form['rowid']
+        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\', Test_Assigned_To=\'%s\', Test_ETA=\'%s\', Test_Review_By=\'%s\', Test_Issue_Type=\'%s\', Test_Updated=now() WHERE Test_Id=%s;' % (str(comment), str(assign_to), str(eta), str(review_by), str(issue_type), str(rowid)))
         mysql.connection.commit()
 
     # Get testcase results of execution id (typically last executed)
@@ -476,18 +484,13 @@ def eid_failures(db, eid):
     cursor = mysql.connection.cursor()
     use_db(cursor, db)
     if request.method == "POST":
-        try:
-            userField = request.form['user']
-            issueField = request.form['issue']
-        except:
-            pass
-        textField = request.form['textField']
-        rowField = request.form['rowField']
-        try:
-            comment = """<b class="text-muted">Review By: </b>""" + str(userField) + """\n</br><b class="text-muted">Issue Type: </b>""" + str(issueField) + """\n</br><b class="text-muted">Comment: </b>""" + str(textField)
-        except:
-            comment = str(textField)
-        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\' WHERE Test_Id=%s;' % (str(comment), str(rowField)))
+        issue_type = request.form['issue']
+        review_by = request.form['reviewby']
+        assign_to = request.form['assignto']
+        eta = request.form['eta']
+        comment = request.form['comment']
+        rowid = request.form['rowid']
+        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\', Test_Assigned_To=\'%s\', Test_ETA=\'%s\', Test_Review_By=\'%s\', Test_Issue_Type=\'%s\', Test_Updated=now() WHERE Test_Id=%s;' % (str(comment), str(assign_to), str(eta), str(review_by), str(issue_type), str(rowid)))
         mysql.connection.commit()
 
     # Get testcase results of execution id (typically last executed)
@@ -500,18 +503,13 @@ def recent_failures(db):
     cursor = mysql.connection.cursor()
     use_db(cursor, db)
     if request.method == "POST":
-        try:
-            userField = request.form['user']
-            issueField = request.form['issue']
-        except:
-            pass
-        textField = request.form['textField']
-        rowField = request.form['rowField']
-        try:
-            comment = """<b class="text-muted">Review By: </b>""" + str(userField) + """\n</br><b class="text-muted">Issue Type: </b>""" + str(issueField) + """\n</br><b class="text-muted">Comment: </b>""" + str(textField)
-        except:
-            comment = str(textField)
-        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\' WHERE Test_Id=%s;' % (str(comment), str(rowField)))
+        issue_type = request.form['issue']
+        review_by = request.form['reviewby']
+        assign_to = request.form['assignto']
+        eta = request.form['eta']
+        comment = request.form['comment']
+        rowid = request.form['rowid']
+        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\', Test_Assigned_To=\'%s\', Test_ETA=\'%s\', Test_Review_By=\'%s\', Test_Issue_Type=\'%s\', Test_Updated=now() WHERE Test_Id=%s;' % (str(comment), str(assign_to), str(eta), str(review_by), str(issue_type), str(rowid)))
         mysql.connection.commit()
 
     # Get last row execution ID
@@ -521,6 +519,15 @@ def recent_failures(db):
     data = cursor.fetchall()
     return render_template('failures.html', data=data, db_name=db)
 
+@app.route('/<db>/ttags/<eid>', methods=['GET', 'POST'])
+def eid_ttags(db, eid):
+    cursor = mysql.connection.cursor()
+    use_db(cursor, db)
+    # Get testcase results of execution id (typically last executed)
+    cursor.execute("SELECT Execution_Id, Test_Name, Test_Status, Test_Tag from TB_TEST WHERE Execution_Id=%s" % eid)
+    data = cursor.fetchall()
+    return render_template('ttags.html', data=data, db_name=db)
+
 @app.route('/<db>/search', methods=['GET', 'POST'])
 def search(db):
     if request.method == "POST":
@@ -607,18 +614,20 @@ def comment(db):
     if request.method == "POST":
         error = request.form['error']
         eid = request.form['eid']
-        issue = request.form['issue']
-        user = request.form['user']
-        commentMsg = request.form['comment']
-        comment = """<b class="text-muted">Review By: </b>""" + str(user) + """\n</br><b class="text-muted">Issue Type: </b>""" + str(issue) + """\n</br><b class="text-muted">Comment: </b>""" + str(commentMsg)
+        issue_type = request.form['issue']
+        review_by = request.form['reviewby']
+        assign_to = request.form['assignto']
+        eta = request.form['eta']
+        comment = request.form['comment']
 
         try:
-            cursor.execute('Update TB_TEST SET Test_Comment=\'{}\' WHERE Execution_Id={} AND Test_Error LIKE \'%{}%\';'.format(comment, eid, error))
+            cursor.execute('Update TB_TEST SET Test_Comment=\'{}\', Test_Assigned_To=\'{}\', Test_ETA=\'{}\', Test_Review_By=\'{}\', Test_Issue_Type=\'{}\', Test_Updated=now() WHERE Execution_Id={} AND Test_Error LIKE \'%{}%\''.format(str(comment), str(assign_to), str(eta), str(review_by), str(issue_type), str(eid), str(error)))
             mysql.connection.commit()
             return render_template('comment.html', error_message="", recent_eid=recent_eid)
         except Exception as e:
             print(str(e))
             return render_template('comment.html', error_message=str(e), recent_eid=recent_eid)
+    
     else:
         return render_template('comment.html', error_message="", recent_eid=recent_eid)
 
